@@ -4,9 +4,8 @@ use crate::{
     option::PureGetterOption,
 };
 use swc_atoms::js_word;
-use swc_common::{Span, DUMMY_SP};
+use swc_common::{util::take::Take, Span, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{contains_ident_ref, ident::IdentLike};
 use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith};
 
